## scsk_dx_utils
- utils for SCSK Europe DX data team
- modules are in scskutils/ directory

## resources
https://packaging.python.org/en/latest/tutorials/packaging-projects/

## PYPI credentials
- user: emelas
- password: SCSKDXLondon

## PYPI page
https://pypi.org/project/SCSKutils/

## Package Update
- add feature in scskutils/ directory
- change version number on setup.py (e.g. from VERSION = '0.0.3 to VERSION = '0.0.4') and save
- run setup.sh in terminal (you might need to pip install setuptools)
- enter PYPI credentials above

## Package Install:
- pip install SCSKutils

## Package Use:
- from scskutils import module.py (at the moment, only have scskutils.py)
